package com.ruoyi.cs.service;

import java.util.List;
import com.ruoyi.cs.domain.CsTransferRecord;

/**
 * 转单记录Service接口
 * 
 * @author ruoyi
 * @date 2024-05-29
 */
public interface ICsTransferRecordService 
{
    /**
     * 查询转单记录
     * 
     * @param transferRecordId 转单记录主键
     * @return 转单记录
     */
    public CsTransferRecord selectCsTransferRecordByTransferRecordId(String transferRecordId);

    /**
     * 查询转单记录列表
     * 
     * @param csTransferRecord 转单记录
     * @return 转单记录集合
     */
    public List<CsTransferRecord> selectCsTransferRecordList(CsTransferRecord csTransferRecord);

    /**
     * 新增转单记录
     * 
     * @param csTransferRecord 转单记录
     * @return 结果
     */
    public int insertCsTransferRecord(CsTransferRecord csTransferRecord);

    /**
     * 修改转单记录
     * 
     * @param csTransferRecord 转单记录
     * @return 结果
     */
    public int updateCsTransferRecord(CsTransferRecord csTransferRecord);

    /**
     * 批量删除转单记录
     * 
     * @param transferRecordIds 需要删除的转单记录主键集合
     * @return 结果
     */
    public int deleteCsTransferRecordByTransferRecordIds(String[] transferRecordIds);

    /**
     * 删除转单记录信息
     * 
     * @param transferRecordId 转单记录主键
     * @return 结果
     */
    public int deleteCsTransferRecordByTransferRecordId(String transferRecordId);
}
